@@ -34,7 +34,7 @@ class LeaseManager:
         self.lease_seconds = lease_seconds
 
     def start(self, loop=None):
-        loop = asyncio.get_event_loop()
+        loop = loop or asyncio.get_event_loop()
         self.future = loop.run_in_executor(
             self.executor, self.autorenew, self.event, self.headers, self.task,
             self.lease_seconds)
@@ -44,7 +44,11 @@ class LeaseManager:
         if not self.future:
             return
         self.event.set()
-        return await self.future
+        try:
+            return await self.future
+        except concurrent.futures.process.BrokenProcessPool:
+            # if the ProcessPool broke, hopefully it did so before renewing
+            return self.task
 
     @staticmethod
     def autorenew(event, headers, task, lease_seconds):
@@ -151,9 +155,21 @@ class TaskManager:
         name = task['name']
         payload = decode(task['pullMessage']['payload'])
 
-        autorenew = LeaseManager(self.manager.Event(), self.executor,
-                                 await self.tq.headers(), task,
-                                 self.lease_seconds).start()
+        autorenew = None
+        try:
+            autorenew = LeaseManager(self.manager.Event(), self.executor,
+                                     await self.tq.headers(), task,
+                                     self.lease_seconds).start()
+        # N.B. theoretically, we should only catch
+        # concurrent.futures.process.BrokenProcessPool but I've come across
+        # several other errors (such as EOFError and ConnectionRefusedError)
+        # and at this point I'm sick of having to update the blacklist. If we
+        # get an exception while creating a LeaseManager, that's enough for me
+        # to be reasonably sure the pool is broken without needing proof.
+        except Exception as e:  # pylint: disable=broad-except
+            log.error('process pool broke, quitting TaskManager')
+            log.exception(e)
+            self.running = False
 
         try:
             async with self.semaphore:
@@ -166,7 +182,8 @@ class TaskManager:
                               name)
                     log.exception(e)
 
-                    task = await autorenew.stop()
+                    if autorenew is not None:
+                        task = await autorenew.stop()
                     await self.tq.delete(task)
                     await self.fail(task, payload, e)
                     return
@@ -174,7 +191,8 @@ class TaskManager:
                     log.error('failed to process task: %s', name)
                     log.exception(e)
 
-                    task = await autorenew.stop()
+                    if autorenew is not None:
+                        task = await autorenew.stop()
 
                     tries = task['status']['attemptDispatchCount']
                     if self.retry_limit is None or tries < self.retry_limit:
@@ -187,10 +205,14 @@ class TaskManager:
                     return
 
                 log.info('successfully processed task: %s', name)
-                task = await autorenew.stop()
+                if autorenew is not None:
+                    task = await autorenew.stop()
                 await self.tq.ack(task)
+        except Exception as e:  # pylint: disable=broad-except
+            log.exception(e)
         finally:
-            await autorenew.stop()
+            if autorenew is not None:
+                await autorenew.stop()
 
     def start(self):
         if self.running:
